FiberRouteNode class sealed

Constructors

FiberRouteNode.node({required String name, FiberRouteNode? main, Widget? redirect(BuildContext)?, required List<FiberRouteNode> routes})
const
factory

Properties

controllerWidgetType Type?
no setter
hashCode int
The hash code for this object.
no setterinherited
name String?
final
pageBuilder Page Function(BuildContext, GoRouterState)?
final
routes List<FiberRouteNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

controller<T extends Widget>({required String name, RouteTransition transition = RouteTransition.none, bool gesturePopEnabled = false, Widget builder(BuildContext context, Widget child, [Object? extra])?, required List<FiberRouteNode> routes}) FiberRouteNode
shell({required String name, required Widget builder(BuildContext context, Widget child, [Object? extra]), required List<FiberRouteNode> routes}) FiberRouteNode
view<T extends Widget, P extends Object?>({required String name, RouteTransition transition = RouteTransition.system, bool gesturePopEnabled = true, required Widget builder(BuildContext, P?)}) FiberRouteNode